Building installers
===================

.. module:: nsist

.. autoclass:: InstallerBuilder
   
   .. automethod:: run

   .. automethod:: fetch_python_embeddable

   .. automethod:: write_script

   .. automethod:: prepare_shortcuts

   .. automethod:: prepare_packages

   .. automethod:: copy_extra_files
   
   .. automethod:: write_nsi

   .. automethod:: run_nsis
